@@ -14,9 +14,15 @@
 #' @export
 list0 <- function(...) {
   e <- as.list(substitute(list(...)))[-1L]
-  do.call(list, e[e != substitute()], envir = parent.frame(2))
+  do.call(list, e[is_not_empty(e)], envir = parent.frame(2))
 }
 
 #' @export
 #' @rdname list0
 lst <- list0
+
+is_not_empty <- function(x) {
+  # https://jmbarbone.github.io/posts/wat-na-list/
+  x <- x != substitute()
+  x | is.na(x)
+}
